package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````L1H!`#0```"XL@```@0`!30`(``)
M`"@`'``;``$``'",IP``C*<!`(RG`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"8IP``F*<```4```````$`
M`0```/2N``#TK@(`]*X"`$`"``"($@``!@```````0`"`````*\```"O`@``
MKP(```$````!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D]*X`
M`/2N`@#TK@(`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50`40,ZY82NL_,HZQ]V4/70L82[^VV$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%8```!8````````````````````
M`````%D```!=`````````%\`````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]
M]MOW`%X&I(?_`:\TZ+%(G>?.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`"
M;7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)B
MV^VYC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^
MJ9R;8M#Z@NPL]HMK?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM
M.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;>J\J?R=6R
M<0`````````````````````1```````````````@````+0``````````````
M(````#P``````````````"````!0```````````````@````A`,`````````
M````$@```$<"`````````````!(```#>`@`````````````2````P@(`````
M````````$@```'<$```DL0(``````"``%P#-`0`````````````2````NP(`
M````````````$@```+T!``#L%0$``````!(````#!0``\68!`#`````2``T`
MX`,``#2Q`@``````$``8`'4"`````````````!(```"@`@`````````````2
M````MP0``#"Q`@`$````$0`7`"$#`````````````!(````?!0``T6,!`-0"
M```2``T`7`0``!%9`0"H````$@`-`(L#`````````````!(```"&`@``````
M```````2````,@,`````````````$@```.\#``!\P0(``````!``&``/`0``
M```````````2````.@0`````````````$@```&@$``!=7`$`=`<``!(`#0"1
M!```X58!`)(````2``T`3P0``/E8`0`6````$@`-`*T"`````````````!(`
M``!P`@`````````````2````E@$`````````````$@````X#````````````
M`!(```">`P``.+$"``0````A`!@`+P(`````````````$@```#8"````````
M`````!(```#0`@`````````````2````S0,``#2Q`@``````$``7`.L"````
M`````````!(```">````+!@!```````2````M0(`````````````$@```%8#
M`````````````!(````I`@`````````````2````3P(`````````````$@``
M`)\#```XL0(`!````"$`&`#Z`P``?,$"```````0`!@`*P,``%"Q`@`$````
M$0`8``<$``!Q9P$``@```!(`#0"A`0`````````````2````;P$`````````
M````$@```*<$```Q9P$`0````!(`#0#C!```H5L!`+P````2``T`$00``'1G
M`0``````$@`.`(\"`````````````!(```![!```L1H!```````2``T`T`0`
M`%05`0``````$@`+`+X``````````````!(``````P`````````````2````
M`@$``$RQ`@`!````$0`8`,D"`````````````!(```""!```?&<!``0````1
M``\`U`,``#2Q`@``````$``8`%T#`````````````!(```!U`P``````````
M```2````:@``````````````$@```!P!`````````````!(```#.!```;58!
M`#`````2``T`.`$`````````````$@````($``!\P0(``````!``&`#6!```
M>5<!`'X!```2``T`TP``````````````$@```%X"`````````````!(```"'
M```````````````2````%0(`````````````$@```*\!`````````````!(`
M``#A```````````````2````\P``````````````$@```"T!``!(L0(`!```
M`!$`&`"=`P``.+$"``0````1`!@`80$`````````````$@```-<"````````
M`````!(```#N`P``?,$"```````0`!@`]00``$%;`0!0````$@`-`*\`````
M`````````!(````9`P`````````````2````=00``"2Q`@``````$``7`&<#
M`````````````!(```"[`P``0+$"``0````1`!@`*`0``)%;`0`0````$@`-
M`.L!`````````````!(```#8`0`````````````2````F`,``,$8`0#P`0``
M$@`-`#T!`````````````!(```!"`P`````````````2````.0,`````````
M````$@```/8!``!4L0(`$P```!$`&`#Y`@`````````````2````Y0(`````
M````````$@```'T"`````````````!(```#D`0`````````````2````?0,`
M````````````$@```,$$``"Y60$`B`$``!(`#0!)`P`````````````2````
M0@$`````````````$@```*<"`````````````!(```!#!```I68!`$P````2
M``T`>```````````````$@```'\!`````````````!(````7!```=5<!``0`
M```2``T`B`$`````````````$@```$X!``"T%P$``````!(`````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%R;6AF+G-O
M+C,`7U]S=&%C:U]C:&M?9W5A<F0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?
M9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I
M;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT`````````````````@`#
M``(``@`!`````@````$``0`"``(``0`"``$``0`"``(``@`!`````@`!``$`
M`0`"``(````"``(``P`#``(``0`"`````@`"``,``P`"``$``@`!```````!
M``$``0`"``$``0````(````"``$``0`"``(```````$````!``$````"````
M`P````````````(````"``$``0````(``0`"``0``0```````0`"``(``@``
M``(``@`"``(``@`!``(````"``$```````$```````$``0"G`P``$````"``
M```4:6D-```$`#4%`````````0`!``4"```0````(````!1I:0T```,`-04`
M```````!``$`5`(``!``````````%&EI#0```@`U!0```````""Q`@`5`@``
M.+$"`!1/``!`L0(`%%@``$BQ`@`43@``3+$"`!0[``!0L0(`%"\``%2Q`@`4
M8```#+`"`!8'```0L`(`%@4``!2P`@`6&@``&+`"`!8L```<L`(`%A<``""P
M`@`60```)+`"`!9=```HL`(`%D<``"RP`@`680``,+`"`!9>```TL`(`%@P`
M`#BP`@`68@``/+`"`!94``!`L`(`%D0``$2P`@`6.@``2+`"`!8V``!,L`(`
M%D@``%"P`@`6$```5+`"`!8>``!8L`(`%C$``%RP`@`64```8+`"`!9?``!D
ML`(`%F<``&BP`@`63```;+`"`!9:``!PL`(`%@8``'2P`@`6;@``>+`"`!9;
M``!\L`(`%E4``("P`@`6(P``A+`"`!9D``"(L`(`%A4``(RP`@`6,@``D+`"
M`!8"``"4L`(`%@@``)BP`@`6'P``G+`"`!8E``"@L`(`%FL``*2P`@`6*@``
MJ+`"`!89``"LL`(`%B0``+"P`@`65P``M+`"`!8Y``"XL`(`%F,``+RP`@`6
M(```P+`"`!9I``#$L`(`%E$``,BP`@`6;P``S+`"`!9!``#0L`(`%F@``-2P
M`@`6"@``V+`"`!8G``#<L`(`%D(``."P`@`6"P``Y+`"`!9E``#HL`(`%CP`
M`.RP`@`62P``\+`"`!8H``#TL`(`%C\``/BP`@`630``_+`"`!9L````L0(`
M%DD```2Q`@`6$@``"+$"`!8/```,L0(`%BD``!"Q`@`6*P``%+$"`!8A```8
ML0(`%A8``!RQ`@`62@``"$`MZ6`!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y9":
M`0``QH_B&<J,XI#ZO.4`QH_B&<J,XHCZO.4`QH_B&<J,XH#ZO.4`QH_B&<J,
MXGCZO.4`QH_B&<J,XG#ZO.4`QH_B&<J,XFCZO.4`QH_B&<J,XF#ZO.4`QH_B
M&<J,XECZO.4`QH_B&<J,XE#ZO.4`QH_B&<J,XDCZO.4`QH_B&<J,XD#ZO.4`
MQH_B&<J,XCCZO.4`QH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`QH_B&<J,XB#Z
MO.4`QH_B&<J,XACZO.5X1\!&`,:/XAG*C.(,^KSE`,:/XAG*C.($^KSE`,:/
MXAG*C.+\^;SE`,:/XAG*C.+T^;SE`,:/XAG*C.+L^;SE`,:/XAG*C.+D^;SE
M`,:/XAG*C.+<^;SE`,:/XAG*C.+4^;SE`,:/XAG*C.+,^;SE`,:/XAG*C.+$
M^;SE`,:/XAG*C.*\^;SE`,:/XAG*C.*T^;SE`,:/XAG*C.*L^;SE`,:/XAG*
MC.*D^;SE`,:/XAG*C.*<^;SE`,:/XAG*C.*4^;SE`,:/XAG*C.*,^;SE`,:/
MXAG*C.*$^;SE`,:/XAG*C.)\^;SE`,:/XAG*C.)T^;SE`,:/XAG*C.)L^;SE
M`,:/XAG*C.)D^;SE`,:/XAG*C.)<^;SE`,:/XAG*C.)4^;SE`,:/XAG*C.),
M^;SE`,:/XAG*C.)$^;SE`,:/XAG*C.(\^;SE>$?`1@#&C^(9RHSB,/F\Y7A'
MP$8`QH_B&<J,XB3YO.4`QH_B&<J,XASYO.4`QH_B&<J,XA3YO.4`QH_B&<J,
MX@SYO.4`QH_B&<J,X@3YO.4`QH_B&<J,XOSXO.4`QH_B&<J,XO3XO.4`QH_B
M&<J,XNSXO.4`QH_B&<J,XN3XO.4`QH_B&<J,XMSXO.4`QH_B&<J,XM3XO.4`
MQH_B&<J,XLSXO.4`QH_B&<J,XL3XO.4`QH_B&<J,XKSXO.4`QH_B&<J,XK3X
MO.4`QH_B&<J,XJSXO.4`QH_B&<J,XJ3XO.5X1\!&`,:/XAG*C.*8^+SE`,:/
MXAG*C.*0^+SE`,:/XAG*C.*(^+SE`,:/XAG*C.*`^+SE`,:/XAG*C.)X^+SE
M`,:/XAG*C.)P^+SE`,:/XAG*C.)H^+SE`,:/XAG*C.)@^+SE\+5+\D`7P/("
M!XFP.V@%D`6H!)$$J0.2`ZH'D__W*N]!\K1R0?8L`,#R`0+`\@$`$48$\!7_
M2_),$\#R`@,=>``M`/"0@$OR2!3`\@($(&C_]]#OD/C>,P)&(&A#\`(#@OC>
M,__WQN\%FY_M75L%,P?ND#J?[5QKN.YG>S?N!7NT[L9[\>X0^I#XWB-"\`$"
M@/C>(P#SB("8`$SR8";_]Z[N!)Q+\BP3!9K`\@(#P/("!@$J1O80,<#R`0$%
M1EAH(VA&^/!<J&!/\`0`*V!&]A0SP/(!`VE@ZV#$OP7Q#`$C'4;X]`S(OP3K
M@@0%W5/X!`NC0D'X!`_YT0+Q@$1%\IUA`S1/\``.*T;-^`#@5OCH#`,R1?@D
MX,#R`0'_]_SN3/)@(\#R`@,$1HBS5OCH#$SR8"7_]S+N1O;```:IP/(!`,#R
M`@4#\,/[.+-6^.@,__?^[?_WU.X'FCMH($::0CC1";#PO?_W..Y,\F`CP/("
M`T/XZ`QXLTOR2!3_]^+MP/("!"!H__<V[X#X+59>YU/XZ`S_]_SN!$;'YU7X
M[`Q@L03P'_[1YTOR5!%&]NP0P/("`<#R`0#_]WKN1O9<``:IP/(!``/P@_M%
M^.P,`"B\T.;G__?([0$@__=`[@"_`````````````(#____/04_P``M/\``.
M`KQJ1@2T`;3?^!#`3?@$S0-(!$O_]P[N__?8[G%G`0#!&`$`,6<!`!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`0'__^H0E0$`(`$```=+2_(T$,#R`@`;&@8K
M!=E`\@`#P/(``P.Q&$=P1P"_-[$"`$OR-!-+\C00P/("`\#R`@`9&HD0`>O1
M<4D0!=!`\@`#P/(``P.Q&$=P1P"_$+5+\F<4P/("!"-X&[G_]\__`2,C<!"]
M2O;\8`BUP/("``-H$[F]Z`A`T^=`\@`#P/(``P`K]M"81_3G+>GP3TOR0!.M
M]3]]P/("`P)&.#(-\7@)&Y,;:`%&&I`!\7@,$$9.1@=&O9/-^"B0S>D,JY?H
M"@`(-V=%3^H3:T_J$R5/ZA%J3^H!(DKJ`RI/ZA$D`))$Z@-DS?@$H$_J`R)/
MZ@-N`I+=Z0`C3_```YE&3^H!803T?T`"]'\"3_```\WX#+`%DTM&0NH!`D_P
M``&`1HE&W>D"`4_P``$$E0#T?P#-^!BP0.H.`,WI"`%`1D#J`@!/\``!!Y%)
M1D'J`P$"1@KP_P`+1D+J``A/\``!0^H!"=WI!!)/\``"1ND"B0'T?T$(1A%&
MW>D((T+J``)#Z@$#$$891MWI!B-/\``#0^H!`P+P_P)"Z@`"&4801N;H!`&-
MT=WX*)`TJ"JI#?%H#@WQZ`Q/\$`(^>D"9_'I`B/PZ0)%S>D`9X+J!`:#Z@4'
M_ND"13)&.T;=Z0!G5D!?0&9`;T"T&;CQ`0A/ZM9Z3_```TKJ1PI*Z@0&,D;L
MZ0(CVM$:G`WU/GY^Z:(!U.D`(R5&S>D"`1=&F$8`(@`C^0[-Z0`C`)&21M3I
M"`$L1M7I`E:;1LWI!'AZ`<WI%`$`F<WI#%9%1D'J2!$`D>D.`9'4Z08!)4;=
MZ12)U>D$9\WI#@'=Z0(!#_;T5-3I`#00ZP@`S>D(9T'K"0$;&-WI#E9,0=WI
M#`'=Z0")S>D"-"7J``,FZ@$$2.H""`9&`D8E1@]&'$8+1MWI"`$&0`]`4$99
M1LWI``$T0]WI`@$]0T_JD@H?1A#K"`!*ZH=Z0?$``;L'$.L$"`&33_``!D_J
M@G/-^`2@3_``!P"30>L%"3-&S>D*B3Q&S>D"--WI`"-/\``)3_``"][I`D5"
MZ@H"3^I)$0.164801MWI!"/-Z08!3^K89@+J``H#Z@$+S>D`JT;J21;=Z0Z\
MW>D(`1OK!`L#EB#J`@(AZ@,#7$;=Z0"K3^I($0*12NH""@_V`%+2Z0`23.L%
M#$OJ`PL)&4_P``!"ZPP"$T8*1@`AS>D``=WI`@$P0Q+K"@9#ZPL'W>D$JS(8
M4T861D_JDP,`DP":1_$``UE&4$8?1D+JBW,`DXL(`9,`(@`CS>D"(]WI`".R
M1LWI$&>$!_8.`I8B0P*;3_``"P`G%D9#ZDL3`I-/ZDH0W>D*(][I!$4R0#M`
MS>D*9Q9&'T;=Z0@C$AE/ZMMD:T$#E`_V6$75Z0!%I!A/\``"74'-Z1)%W>D&
M-"3J"00CZ@@#'D,`(R5&+T,T1CU&W>D"9\WI`"-/ZI@#W>D2$@9#`)-/ZHAP
M"1EJ015&BAE%\0`#`"&01A5&'D8`F\WI$E9/ZMAF0^J)<P"33^J9`P&3W>D`
M(P`CWND&14_P``D"0T;J21801@`BS>D`(P_VS#/3Z0`C$AE/ZDD4:T$!E-WI
M$$7-Z1`!!$`-0`&6($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z0A%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_V&#/3Z0`CS>D&`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z0I%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_V9"/3Z0`CS>D*`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z0Q%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_VL!/3Z0`CS>D0`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z0Y%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_V_`/3Z0`CS>D&`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z1!%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_V2`/3Z0`CS>D*`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z1)%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_RE'/3Z0`CS>D0`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z11%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_RX&/3Z0`CS>D&`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4;>Z19%B$8:1@*;S>D2$@`A0^J)<P*33^J9`P.3W>D"
M(P`C3_``"3)#3^K89D;J21801@`BS>D`(P_R+&/3Z0`C$AE/ZDD4:T$!E-WI
M%D7-Z0H!!$`-0`&6($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z1A%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_R>%/3Z0`CS>D0`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI!D6D&%U!S>D"1=WI"C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J(=J083_```EU!`"/-Z0(C
M(AA/ZI@#`I-%\0`#$4:(1AI&`IM#ZHES`I-/ZID#`Y/-Z1(23_``"=WI`B,`
M(][I&D4`(3)#3^K89D;J21801@`BS>D`(P_RQ$/3Z0`CS>D&`1(93^I)%&M!
M`93=Z19%`98$0`U`($8I1MWI"D6D&%U!S>D"1=WI$#0-1D_J2!$`D2/J"@,D
MZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!`"/-Z0(C
M(AA/ZIH#`I-%\0`#$4;>Z1Q%BD8:1@*;S>D6$@`A0^J+<P*33^J;`P.3W>D"
M(P`C3_``"S)#3^K:9D;J2Q801@`BS>D`(P_R$$/3Z0`CS>D*`1(93^I+%&M!
M`93=Z1)%`98$0`U`($8I1MWI$$6D&%U!S>D"1=WI!C0-1D_J2A$`D2/J"`,D
MZ@D$&D8C1@1&'4,40RM&(D;=Z0)%I!A/\``"74$`(\WI`B-/ZI@#W>D``0*3
M,$-/ZHAV(AA%\0`#WND>11%&&D8"F\WI$A*(1D/JB7,"DT_JF0,#D]WI`B,`
M(T_P``D`(3)#3^K89D;J21801@`BS>D`(]>CT^D`(\WI$`$2&4_J211K00&4
MW>D610&6!$`-0"!&*4;=Z09%I!A=0<WI`D7=Z0HT#49/ZD@1`)$CZ@H#).H+
M!!I&(T8$1AU#%$/=Z0`!*T8B1MWI`D4P0T_JBG:D&$_P``)=00`CS>D"(R(8
M3^J:`P*31?$``Q%&WND@18I&&D8"F\WI%A(`(4/JBW,"DT_JFP,#D]WI`B,`
M(T_P``LR0T_JVF9&ZDL6$$8`(LWI`".KH]/I`"/-Z08!$AE/ZDL4:T$!E-WI
M$D4!E@1`#4`@1BE&W>D*1:0874'-Z0)%W>D0-`U&3^I*$0"1(^H(`R3J"00:
M1B-&!$8=0Q1#W>D``2M&(D;=Z0)%,$-/ZHAVI!A/\``"74$`(\WI`B,B&$_J
MF`,"DT7Q``,11M[I(D6(1AI&`IO-Z1(2`"%#ZHES`I-/ZID#`Y/=Z0(C`"-/
M\``),D-/ZMAF1NI)%A!&`"+-Z0`C?J/3Z0`CS>D*`1(9:T'-Z0(C3^I)$P&3
MW>D6(]WI$$4"0`M``9801AE&W>D"(Q(9:T$41AU&S>D"1=WI!C0-1D_J2!$`
MD2/J"@,DZ@L$&D8C1@1&'4,40]WI``$K1B)&W>D"13!#3^J*=J083_```EU!
M`"/-Z0(C(AA/ZIH#`I-%\0`#`"4<1A-&`IJ:1D+JBW("DD_JFP(#DLWI$#0`
M)-WI`B-/ZMICS>D`14_P``O>Z20!,D-1I=7I`$4`)@"3-T8D&!9&34'-Z0)G
MW>D2`0">.4`00$;J2Q8`EMWI!F=/ZDH2-AEO031&/4;=Z0IG)NH(!B?J"0<&
M0P]#,!E/ZMMA`9%'ZP4!W>D`9P`D`"460RM&(D;-Z0`C@AE/ZHES`9-!\0`#
M3^J8!!%&1.J)=!I&`91/ZHAS`)-/ZID%S>D2$@A&W>D`(T_P``A!1@_RK`G9
MZ0")(D,K0T8!%T841AU&`"(`(\WI`"/##@"3WNDF(\WI!D4`)0"<$NL(`D/K
M"0.I1D3J010`E-WI$$6X1LWI$(D%Z@D%W>D*B3Q`&.L""$GK`PG=Z0(C(NH*
M`B/J"P,B0RM#&.L""$_JT61)ZP,)`91"1D_JBG1+1MWI`(E(Z@8($NL(!D/Q
M``=/ZIH#,D9#ZHMSN$8`DS=&3^J;!LWI"G@=1@7@K_,`@)EY@EH``````99/
M\``(W>D`9T-&)D,O0]0.L4;=Z096ND;-Z0::A>H)!0_VG&O;Z0"K1.I#%`"4
MJ$;>Z2A65`$5ZPH%1NL+!MWI$KR+Z@@+-T;>#@&6V$;=Z0*K&NL%"D_P``5+
MZP<+&NL(!DOQ``?=Z0"K2NH$"H0'%NL*"$_JD`9'\0`)1NJ!=H\(WNDJ`<I&
MP4;-Z1*:3_``"M%&1^H&"T;J!`H`),WI`$5/ZMADW>D&5LWI`JN%Z@H%W>D*
MO`"4+D8/]@!EU>D`18OJ!@LD&$_J2!!>1MWI$*M-00"9&NL$"D_JV61!ZDD1
M`90`D4OK!0L:ZP8$3_```4OQ``7=Z0"K2NH`"I`'%.L*!D_JD@1%\0`'1.J#
M=+)&G0B[1LWI$*M/\``+WNDL(U]&1.H`"P`@S>D``?$.`)$/]HA1T>D``47J
M!`S=Z0)%@!C-Z0J\64'-Z18!!IB$Z@L$`)MR`=WI$JM#ZD<3A$8`DXKJ!`K=
MZ18!5$80ZPP`0?$``0`9BT9/ZM=A`9%+\0`!W>D`JP_V-%S<Z0"\2NH""D_J
MB'(0ZPH$3^J8`$#JB7!!\0`%3^J9`4#J`@E!Z@`*S>D214E&W>D*B5)&S>D&
M$HCJ`0C>Z2X!`"7C#A#K"P#=Z1"K0>L,`<WI%@$"F(KJ"`I#ZD43`)/01F(!
MA$;=Z18!$.L,`$'Q``$0ZP@`BT9/ZM5A`9%+\0`!W>D`JTKJ`@JR!Q#K"@A/
MZI8`0?$`"4#JAW"Y"$#J`@9!Z@`'S>D0B;)&3_``";M&W>D&9\WI`JM11@_V
M=$S<Z0"\3D#>Z3`!3^K88T/J21,`DQ#K"P#=Z1*K0>L,`<WI%@$*F(KJ!@I/
MZD@2`"-61H1&W>D6`1#K#`!!\0`!@!F+1D_JV6$!D4OQ``'=Z0"K2NH""J('
M$.L*!D_JE`!`ZH5P0?$`!T#J`@2I"$'J``7>Z3(!HD8`),WI`#2S1MWI`C2\
M1LWI$KRK1H/J"@/-Z0JK3_``#!Q&\PX`DV=&#_;0,]/I`".`&$_J1A)90<WI
M%@$`FP:80^I,$]WI$*L`DX1&W>D6`8KJ!`H0ZPP`0?$``51&`!F+1D_JUV$!
MD4OQ``'=Z0"K2NH""D_JB'(0ZPH$3^J8`$#JB7!!\0`%3^J9`4#J`@E!Z@`*
M3_``"$E&3_``"<WI`(E21MWI"HGC#LWI!A(`DXCJ`0@/]D0ST^D`(][I-`'=
MZ1*K@!C-Z1!%64'-Z18!`IB*Z@@*`)L`)=!&8@&$1MWI%@%#ZD43`),0ZPP`
M3_```T'Q``$0ZP@`BT9/ZM5A`9%+\0`!W>D`JTKJ`@JR!Q#K"@A/ZI8`0?$`
M"4#JAW"Y"$#J`@M!Z@`,`"+>Z38!S>D`(T_JV&,`DP_VO"/3Z0`CW>D&9X`8
MS>D2B5E!S>D6`0J83_``"0";ANH+!LWI`KQ/ZD@20^I)$]WI$*N$1@"3W>D6
M`8KJ!@H0ZPP`5D9!\0`!@!F+1D_JV6$!D4OQ``'=Z0"K2NH""J('$.L*!D_J
ME`!`ZH5P0?$`!T#J`@2I"$'J``6R1B%&W>D"-+M&S>D0JT_P``LJ1E]&S>D*
M$@_V*"S<Z0"\2T#>Z3@!<@$<1O,.$.L+`-WI$JM!ZPP!S>D6`0:8BNH$"D/J
M1Q,`DU1&`".$1MWI%@$0ZPP`0?$``0`9BT9/ZM=A`9%+\0`!W>D`JTKJ`@I/
MZHAR$.L*!$_JF`!!\0`%0.J)<$_JF0%`Z@()0>H`"@`BWNDZ`<M&S>D`(^,.
M`)/41@_VG!/3Z0`CW>D*B8`8S>D&O%E!S>D6`0*8B.H+"-WI$*MB`0";A$;=
MZ18!BNH("LWI$D40ZPP`3_``!4'Q``%#ZD43T$8`DXM&$.L(`$_JU6$!D4OQ
M``'=Z0"K2NH""K('$.L*"$_JE@!!\0`)0.J'<+D(0.H""D'J``O=Z09G4$;-
MZ1")649&0$]`S>D"`<WI`&=/\``)WND\$D_JV&H/]OP'U^D`9TKJ21H*FXD9
M>D'=Z0!GS>D6$J\(W>D2$LWX!*!.0-WI%@'`&$'Q``&"&4_JE`9/ZH1P1NJ%
M=M[I/D5!\0`#S>D*(T_J2!,`D]WI`",-];A^S>D`14;J``3=Z0(!1^H&!4+J
M"@+=Z0JK8$`N1B5&S>D*5@_VA`75Z0!%!D;=Z0`!&NL""DOQ``O-Z1*K`!E2
M1FE!3_``"P1&!I@-1LWI%D7=Z1!%3^K::DKJ2QK-^`2@=$!;1D_JF0<F1MWI
M%D4D&$7Q``6@&47Q``'-Z08!40$`D=WI``%/ZI@&W>D&O$;JB79`Z@H`3^J(
M=!OK``M/\``(3_``"<WI`(E81D;J!`A'Z@8)3^K09`"41T9,\0`,R$;-Z1:\
M3_``#-[I`*MA1LWI!G@-];Q^W>D*5@">?4`/\L1YV>D`B4;J3!8`EMWI$F<8
MZPH(2>L+"0`G;D`"G1CK!01/ZD`82?$`!:)&S`X:ZP8*`91%\0`+W>D`10`F
MS>D`9T3J"`3-Z0)G&NL$"$_JD@0`E$_J@W0#E$OQ``D`G)X(`9;*1D3J@W0`
ME`.<DP<"D\%&1.J2!`.4W>D`9T1&S>D2FD_P``K=Z0*)54;>Z0`C3^K4:DCJ
M!@A)Z@<)2NI%&LWX!*!&1D]&W>D&B0WUP'[-Z1!G3^J<"8CJ!@@/\@1WU^D`
M9P`AMAA?0<WI`F?=Z19G"IN&Z@@&L$;=Z0)G]AA'\0`'%NL(`D?Q``/-Z0(C
M8P$`D]WI`"-/ZI`(2.J,>(8'0NH*`MWI`JL`(!KK`@I+\0`+S>D6JT_P``M2
M1EM&WND`J\WI``%(Z@8`2>H(`0=&T`Z(1@"0W>D0`<WI"GB!Z@@!#_)\:=GI
M`(D`GGA`&.L*"$;J0QX&GL)&W>D2>$GK"PG-^`#@1T"(Z@$(S>D">!KK!@A/
MZM-F`98"GDGQ``D`)Z$(&.L&"D_P``9)\0`+W>D`B<WI`&=0`0"1J0?-Z0)G
M2.H`"`.1&NL("`"93^J5!@&60$9!ZH5Q`)$#F4OQ``G=Z0!G#?7$?D'JE`&D
M!P.13_``"@*444;-Z0:)3^K0:MWI`HE*ZD$:WND`10WUR'Y(Z@8(2>H'"49&
M3T;=Z0J)3^J3"<WI$F>(Z@8(#_*P5]?I`&<V&6]!S>D"9]WI%E:%Z@@%J$80
MG=WI`F?-^`2@=AE'\0`'%NL(!$?Q``7-Z0)%1`$`E-WI`$5/ZI((2.J#>)8'
M1.H*!-WI`JL`)4GJ"`P:ZP0*2_$`"\WI&*M41LWI`$5(Z@8+`)[>Z0!%#?7,
M?@_R/%K:Z0":W>D2>/(.%.L)!`J>W>D&B47K"@6'Z@L'HD8:ZP8&`9R(Z@<(
M1?$`!P"=%NL("D+J1!(#DLWI$+Q'\0`+;`$"E(0(W>D"9T3J@70"E!9#`"4C
M1HP(`Y0:ZP8(3_``!,WI!D7=Z0)%2_$`"8('1D840QU#WND``<I&\P[!1@:3
MJT;-Z0J:3_``"MWI$(E71@_RI$/3Z0`CHD;-Z1:KB.H$"-WI&*L2&$M!$IB*
MZ@@*^0X=1@:;T$82ZP`*1?$`"QKK"`!#ZD<3!I,'D4OQ``'=Z0:K<@%/\``(
M3_``"4KJ`@I#1A#K"@),1LWI`C1!\0`#$48-]=!^&D8`F\WI!A(`(@A&$49/
MZI,(`9O>Z0"KQ`Y$ZD$4#?74?IL'`Y,!FTCJ@W@!F\WX#(!/ZI,)`)N;!P*3
MW>D"(T+J"`)#Z@D#D$:91MWI%B/-Z1*)@NH(`H/J"0,/\N`YV>D`B1CK"@A)
MZPL)PD;+1MWI"HF(Z@((B>H#"0`B`"/-Z0`C2P$!DQ";S>D"B1KK`PA/ZD`3
M`)-+\0`)`IL!E!CK`PK=Z0`C2?$`"T_JE@@B0TCJAW@:ZP($S?@$@$OQ``5/
MZI<)(T9/\``*+$;-Z1`T`"0:1B-&M`<`E$_P``O=Z0!%S>D"JT3J"`1%Z@D%
MWND`9Z)&JT;5#@*5W>D21<WI"JN$Z@H$#_(T.MKI`)K=Z0:\&>L&"1:=2NL'
M"HOJ!`L`)@`GS>D`9\A&`IY4`0"4`"1&ZD,>7@'-^`C@`99>1LWX!.`8ZP4+
M3^K390.52O$`#!OK!@C=Z0)G3_``!=WI`*M/ZI$'S>D&14_J@'1*Z@8*3^J0
M!@:63/$`"0:>&.L*"P>72?$`#$;J@78&EMWI!@'91MWI"G@U1B!#;*X'0^)&
MS>D6FD_P``K-Z0*:@D8X1MWI$'@I0];I`$4"G@=`BT;-Z1"KN$8/\GPLW.D`
MO$_JUF[=Z0IG&^L$"P.9!NH*!DSK!0Q(Z@8`$IY.ZD$>S?@`X!OK!@C=Z0)G
M3/$`"90(1.J#=`WUW'[]#D_J1AH!E1CK``9)\0`'W>D`B9T(D`=(Z@H(1.H`
M"Q;K"`A%Z@0,1_$`"0`C1T8`),A&S>D8>$_P``C-Z0!XS>D&-`"<W>D0B0&:
MY0X&E=WI%D5(Z@L#WND``1Q`!IL/\M@:VND`FB9&".H+!`J=0^I"$S)&(D,!
MG!GK``E*ZP$*&>L%"`"92O$`"0:3X`X8ZP($!Y!)\0`%W>D&B4_J01K-Z1*\
M2.H*",)&W>D">$9&N`@4ZPH(3^J&<]WI`F=%\0`)<*S*1L%&0.J'<$/JE@.Y
M"+('S>D6FD_P``I71D'J`PM`Z@(*`"/4Z0`!`"3-Z0(T1D;=Z1(TV4;U#@*5
M0^H*`T3J"P3=Z1B\T$8:1B-&#.H##`*;"^H""\WI!KS=Z1*\S>D*B9Y&#_(0
M&=GI`(D+Z@H+W>D&(T[J1QX0G1CK``A<1DGK`0DB0QCK!0A)\0`)_0X8ZP($
MS?@(X`.52?$`!<WI!F=/ZD8:W>D"B0">2.H*"!3K"`ARK$7Q``FP"`"=`9[-
MZ1B)3_``":H'149`ZH9PL0A`Z@(*0>H`"P`FS>D`5M3I``%51EY&`)S=Z0JK
M3_``",WI`HFH1K%&S>D0B5)&*D/E#@*5W>D610*;%$`!FA*=)D941@_R7`K:
MZ0":!.H(!$/J0A,R1B)#`9P9ZP`)`I-*ZP$*&>L%"`"92O$`">`.&.L"!`.0
M2?$`!=WI`HE/ZD$:2.H*",)&W>D&>$9&N`BS!]WI!F<)X*_S`("AZ]EN````
M`-R\&X\`````%.L*"'2L1?$`"4#JAW!#ZI8#N0BR!T#J`@M!Z@,,U.D``0`C
M`"3-Z0(TW>D0-,I&P4;-Z1::3_``"D9&5T;81D/J"P-$Z@P$W>D8J_4.`I7A
M1AI&S>D2B2-&"NH""@OJ`PO-Z0:KW>D0O$_J1AH"FPOJ"`L/]K!IV>D`B0J=
MGD;=Z08C&.L`"%Q&2>L!"2)#&.L%"$[J1QY)\0`)S?@(X!CK`@1/ZM=E`Y5)
M\0`%W>D"B<WI!F<`GDCJ"@@4ZP@(=JQ%\0`)`)VP"`&>S>D8B4_P``FJ!T5&
M0.J&<+$(0.H""D'J``L`)LWI`%;4Z0`!549>1@"<W>D2JT_P``C-Z0*)J$:Q
M1LWI"HE21BI#Y0X"E=WI%D4"FQ1``9H0G29&5$8/]@1JVND`F@3J"`1#ZD(3
M,D8B0P&<&>L`"0*32NL!"AGK!0@`F4KQ``G@#ACK`@0#D$GQ``7=Z0*)3^I!
M&DCJ"@C"1MWI!GA&1K@(LP?=Z09G%.L*"'BL1?$`"4#JAW!#ZI8#N0BR!T#J
M`@M!Z@,,RD;4Z0`!P48`(\WI%IH`),WI`C1/\``*W>D*-$9&5T;81D/J"P-$
MZ@P$W>D8J_4.`I7A1AI&(T8*Z@(*"^H#"P*;S>D&JT_J1AK=Z0J\S>D0B9Y&
M"^H("P_V/%G9Z0")W>D&(T[J1QX2G1CK``A<1DGK`0DB0QCK!0C-^`C@2?$`
M"?T.&.L"!`.52?$`!=WI`HG-Z09G`)Y(Z@H(%.L("'JL1?$`"0"=L`@!GLWI
M&(E/\``)J@=%1D#JAG"Q"$#J`@I!Z@`+`";-Z0!6U.D``55&7D8`G-WI$*M/
M\``(S>D"B:A&L4;-Z1*)4D8J0^4.`I7=Z19%`IL40`&:"ITF1E1&#_:02MKI
M`)H$Z@@$0^I"$S)&(D,!G!GK``D"DTKK`0H9ZP4(`)E*\0`)X`X8ZP($`Y!)
M\0`%W>D"B4_J01I(Z@H(PD;=Z09X1D:X"+,'W>D&9Q3K"@A\K$7Q``E`ZH=P
M0^J6`[D(L@=`Z@(+0>H##-3I``$`(P`DS>D"--WI$C3*1L%&S>D*FD_P``I&
M1E=&V$9#Z@L#1.H,!-WI&*OU#@*5X48:1B-&"NH""@OJ`PL"F\WI%JM/ZD8:
MW>D2O,WI!HF>1@OJ"`L/]L@YV>D`B1"=3NI''MWI%B,8ZP`(7$9)ZP$)(D,8
MZP4(S?@(X$GQ``G]#ACK`@0#E4GQ``7=Z0*)#?4`?LWI$&<`GDCJ"@@4ZP@(
M?JQ%\0`)`)VP"`&>S>D`B:H'U.D`14#JAG"Q"$#J`@I!Z@`+W>D&(P`F4$99
M1@)#"T,W1D9&$$891MWI"B/01ME&S>D*B0)`"T#-Z0(C0$;=Z08C3^K6:@_V
M)#G9Z0")2NI'&@)`$IO=Z0(!&.L$"$GK!0E/ZM=K$$,8ZP,"2?$``T_J1A@2
M&$/Q``/-Z0(C2.H*`DKJ"P/-Z1(CW>D0B=WI`JM#1IP($IM$ZHET&NL#"DM&
M3^J3!4-&3^J#<-!&2_$`"\WI$*M$Z@`*WND``47J!`M/\``)4T9/ZMAJS>D2
M`5Q&W>D*$DKJ21K-Z0(T#?44?AE#(D/=Z0`T"$840`-`W>D*$LWI`#3=Z0(T
M#_9P)=7I`$490``C"D;=Z1(!`!EI001&#4;=Z0`!$$,`(LWI`"-/ZDD3`9,&
MF\WX!*#B&$_J2!1%\0`#`)02&$_JE@1#\0`#S>D&(]WI`"-$ZH=TO0BP!T+J
M"@+=Z0:K`"<:ZP(*W>D"(TOQ``O-Z1*K5D9%Z@0+1.H`"H*M648+0U!&`D/-
MZ08!&4801MWI$"/5Z0!%3^K6:@)`"T#=Z08!2NI'&LWI`"/=Z0(C`","0`_V
MO!'1Z0`!`!EI001&#4;=Z0`!$$,`(LWI`"-[`0&3"IO-^`2@XAA/ZD841?$`
M`P"4$AA/ZI@$0_$``\WI"B/=Z0`C1.J)=$_JF05/ZHAP0NH*`MWI"JM/\``)
M&NL""DOQ``O-Z1"K1>H$"X2MT$9$Z@`*U>D``5Q&4T;-Z0HT3^K8:LWI``%*
MZDD:W>D&$AE#(D/=Z1)%"$850`1`W>D&$LWI$D7=Z0HT#_84%=7I`$490``C
M"D;=Z0`!`!EI001&#4;=Z1(!$$,`(LWI`"-/ZDD3`9,"F\WX!*#B&$_J2!1%
M\0`#`)02&$_JE@1#\0`#S>D"(]WI`"-$ZH=TO0BP!T+J"@+=Z0*K`"<:ZP(*
MW>D*(TOQ``O-Z1*K5D9%Z@0+1.H`"H:M648+0U!&`D/-Z0(!&4801MWI$"/5
MZ0!%3^K6:@)`"T#-Z0`C2NI'&MWI"B,`(]WI`@$"0`_V8`'1Z0`!`!EI001&
M#4;=Z0`!$$,`(LWI`"-[`0&3!IO-^`2@XAA/ZD841?$``P"4$AA/ZI@$0_$`
M`\WI!B/=Z0`C1.J)=$_JF05/ZHAP0NH*`MWI!JM/\``)&NL""DOQ``O-Z1"K
M1>H$"XBMT$9$Z@`*U>D``5Q&4T;-Z08T3^K8:LWI``%*ZDD:W>D"$AE#(D/=
MZ1)%"$850`1`W>D"$LWI$D7=Z08T#_*X==7I`$490``C"D;=Z0`!`!EI001&
M#4;=Z1(!$$,`(LWI`"-/ZDD3`9,*F\WX!*#B&$_J2!1%\0`#`)02&$_JE@1#
M\0`#S>D*(]WI`"-$ZH=TO0BP!T+J"@+=Z0JK`"<:ZP(*W>D&(TOQ``O-Z1*K
M5D9%Z@0+1.H`"HJM648+0U!&`D/5Z0!%3^K6:LWI"@$01AE&W>D0(TKJ1QH"
M0`M`W>D*`<WI`"/=Z08C`","0`_R!''1Z0`!`!EI001&#4;=Z0`!$$,`(LWI
M`"-[`0&3`IO-^`2@XAA/ZD841?$``P"4$AA/ZI@$0_$``\WI`B/=Z0`C1.J)
M=$_JF05/ZHAP0NH*`MWI`JM/\``)&NL""DOQ``O-Z1"K1>H$"XRMT$9$Z@`*
MU>D``5Q&4T;-Z0(T3^K8:LWI``%*ZDD:W>D*$AE#(D/=Z1)%"$850`1`W>D*
M$LWI$D7=Z0(T#_)<9=7I`$490``C"D;=Z0`!`!EI001&#4;=Z1(!$$,`(LWI
M`"-/ZDD3`9,&F\WX!*#B&$_J2!1%\0`#`)02&$_JE@1#\0`#S>D&(]WI`"-$
MZH=TO0BP!T+J"@+=Z0:K`"<:ZP(*2_$`"\WI$JM61D7J!`M$Z@`*W>D"(UE&
MCJU01@M#`D/-Z08!&4;5Z0!%$$;=Z1`C3^K6:@)`"T#=Z08!2NI'&LWI`"/=
MZ0(C`","0`_RJ%'1Z0`!`!EI001&#4;=Z0`!$$,`(LWI`"-[`0&3"IO-^`2@
MXAA/ZD841?$``P"4$AA/ZI@$0_$``\WI"B/=Z0`C1.J)=$_JF05/ZHAP0NH*
M`MWI"JM/\``)&NL""DOQ``O-Z1"K1>H$"Y"MT$9$Z@`*U>D``5Q&4T;-Z0HT
M3^K8:LWI``%*ZDD:W>D&$AE#(D/=Z1)%"$850`1`W>D&$LWI$D7=Z0HT#_(`
M5=7I`$490``C"D;=Z0`!`!EI001&#4;=Z1(!$$,`(LWI`"-/ZDD3`9,"F\WX
M!*#B&$_J2!1%\0`#$AA#\0`#`)3-Z0(CM`C=Z0`C1.J'=-WI`KR]"$+J"@*P
M!QOK`@M/\``'3/$`#,WI$KQ%Z@0,DJU>1D3J``O5Z0`C\`[=Z0I%0.I'$,WI
M`KQ$Z@L$W>D0JT7J#`4!D`KJ!`H+Z@4+W>D*14_JF07-Z1"KW>D"JP3J"@0/
M\DA+V^D`JQKK`@I+ZP,+W>D0(P:;%$,:ZP,*3^I&$P"32_$`"]WI`",:ZP0*
M2_$`"T_JF`0"0T3JB70:ZP(``91+\0`!"D8!1LWI$!)/ZHAQ`"(`D1-&`D;=
MZ0`!3^K2:MWI`HE*ZD,:($,I0XCJ``C>Z0!%S>D&`4_JEPGUH='I``$-]1I^
MS?@$H"08"IA-0<WI%D7=Z1)%A.H(!*!&W>D612081?$`!13K"`!%\0`!S>D*
M`5$!`)'=Z0`!3^J6"$CJAWB6KT#J"@#=Z0JKM`<:ZP`*2_$`"\WI$JO7Z0!G
M4$9/\``+3^K::DKJ2QI91LWI`&=(Z@0&2>H(!]WI!HDU1D_JDPF(Z@4(/D;-
MZ0I6W>D`9\^EU>D`1<WX!*`V&6]!-$8]1LWI%D7=Z1!6W>D69X7J"`6H1@*=
M=AE'\0`'%NL(!$?Q``7-Z0)%1`$`E-WI`$5/ZI((W>D"O$CJ@WA$Z@H$E@<;
MZP0+F*M,\0`,S>D0O%Q&2>H(#$CJ!@O=Z0IXT^D`(^)&V4:'Z@L'#_+`+-SI
M`+P`)>8.N$8;ZP(+S>D"FDSK`PQ&ZD43W>D29T_JD0G-Z1:\3^I$&H;J"`8`
MDP:;L$;=Z19G]AA/ZM5C1_$`!P&3%NL(`D_JD`A'\0`#2.J!>,WI!B.&!]WI
M`"/>Z0`!#?4<?D+J"@+=Z0:KS>D``4CJ!@!)Z@@!W>D"B1KK`@J/I]?I`&=+
M\0`+B.H`",WI$JM/ZI4)S>D&`5)&W>D``4_P``M/ZMIJ6T:`&4KJ2QIY0<WX
M!*`&1@J8#T;-Z19GW>D09X;J"`:P1MWI%F<V&$?Q``<6ZP@`3^J4"$_JA'9(
MZH5XWND`14?Q``'-Z0H!40$`D=WI``$-]2!^S>D`14CJ!@1)Z@@%W>D&>-WI
M"KQ`Z@H`9T`N1B5&S>D*5KA&W>D`16:GU^D`9QOK``M,\0`,3^J3":096$9]
M0<WI$+PF1D_P``PO1LWI%F?=Z1)63^K;:MWI%F=*ZDP:A>H(!<WX!*"H1@*=
M=AE'\0`'%NL(!$_JD@A/ZH)V2.J#>)ZK1_$`!<WI`D73Z0`C1`$`E-WI`$4`
M)<WI`"-(Z@8"2>H(`]WI"HE$Z@H$W>D"JT.GU^D`9XCJ`@C-Z0(C&NL$"MWI
M`"-+\0`+S>D2JU1&DAE/ZMIJ>T%*ZD4:%D9/ZIP)'T;-Z19GW>D09P:;ANH(
M!LWX!*"P1MWI%F?V&$?Q``<6ZP@"1_$``\WI!B-C`0"3W>D`(T_JD`A(ZHQX
MA@="Z@H"W>D&JTGJ"`S>Z0`!&NL""@WU(GY+\0`+S>D0JT_P``M21EM&2.H&
M"]WI`GCB1ME&U@Z'Z@L'#_)D#-SI`+S-Z0::3^J5"1OK``NX1DSK`0Q&ZD,1
MW>D29T_J0AK-Z1:\ANH(!@J8`)'9#K!&W>D69P&1-AA'\0`'%NL(`$_JE`A/
MZH1V2.J%>-[I`$5'\0`!".``O]R\&X\`````UL%BR@````#-Z0H!W>D``0WU
M)G[-Z0!%2.H&!$GJ"`7=Z0:)W>D*O$#J"@`N1HCJ!`@E1LWI"E8/\N1WU^D`
M9QOK``O=Z0!%3/$`#%A&S>D2O*093_``#'U!3^K;:B9&2NI,&B]&S>D69]WI
M$%9/ZI,)W>D69X7J"`7-^`2@J$8"G7891_$`!Q;K"`1'\0`%S>D"140!`)3=
MZ0!%3^J2"$CJ@WB6!T3J"@3=Z0*KI*L`)1KK!`I+\0`+S>D0JU1&2>H("TCJ
M!@K=Z0IXT^D`(^8.S>D"JX?J"@</\D1[V^D`JT_JG`FX1AKK`@I+ZP,+1NI%
M$]WI$F?-Z1:K3^I$&X;J"`8`DP:;L$;=Z19G]AA/ZM5C1_$`!Q;K"`)/ZH!V
M3^J0"-[I``%(ZHQX`9-'\0`#S>D&(PWU*'[=Z0`CS>D``4CJ!@!)Z@@!W>D"
MB4+J"P+=Z0:K#_+(9]?I`&>(Z@`(S>D&`1KK`@K=Z0`!2_$`"U)&S>D2JX`9
M3_``"WE!3^K::@9&"I@/1LWI%F?=Z1!G2NI+&LWX!*!;1H;J"`9/ZI4)L$;=
MZ19G-AA'\0`'%NL(`$?Q``'-Z0H!40$`D=WI``%/ZI0(W>D*O$CJA7A`Z@H`
MI@<;ZP`+3/$`#,WI$+S>Z0!%6$9/\``,3^K;:DKJ3!H-]2Q^S>D`14CJ!@1)
MZ@@%W>D&>$_JDPEG0"Y&)4;-Z0I6N$;=Z0!%#_(`9]?I`&?-^`2@I!E]029&
M+T;-Z19GW>D25MWI%F>%Z@@%J$8"G7891_$`!Q;K"`1/ZI((3^J"=DCJ@WBJ
MJT?Q``7-Z0)%T^D`(T0!`)3=Z0!%`"7-Z0`C2.H&`DGJ"`/=Z0J)1.H*!-WI
M`JL/\I17U^D`9XCJ`@C-Z0(C&NL$"MWI`"-+\0`+5$;-Z1*KDAE/ZMIJ>T%*
MZD4:%D;-^`2@'T;-Z19GW>D09T_JG`D&FX;J"`:P1MWI%F?V&$?Q``<6ZP@"
M1_$``\WI!B-C`0"3W>D`(T_JD`A(ZHQXA@="Z@H"W>D&JTGJ"`S>Z0`!&NL"
M"@WU+GY+\0`+S>D0JT_P``M21EM&2.H&"]WI`GCB1ME&U@Z'Z@L'#_+H3-SI
M`+S-Z0::3^J5"1OK``NX1DSK`0Q&ZD,1W>D29T_J0AK-Z1:\ANH(!@J8`)'9
M#K!&W>D69P&1-AA'\0`'%NL(`$_JE`A/ZH1V2.J%>-[I`$5'\0`!S>D*`=WI
M``$-]3)^S>D`14CJ!@1)Z@@%W>D&B=WI"KQ`Z@H`+D:(Z@0()4;-Z0I6W>D`
M11OK``L/\E1'U^D`9TSQ``Q81LWI$KRD&4_P``Q]04_JVVHF1DKJ3!HO1LWI
M%F?=Z1!63^J3"=WI%F>%Z@@%S?@$H*A&`IUV&4?Q``<6ZP@$1_$`!<WI`D5$
M`0"4W>D`14_JD@A(ZH-XE@=$Z@H$W>D"J["K`"4:ZP0*2_$`"\WI$*M41DGJ
M"`M(Z@8*W>D*>-/I`"/F#H?J"@?-Z0*K#_*\.]OI`*M/ZIP)N$8:ZP(*2^L#
M"T;J11/=Z1)GS>D6JT_J1!N&Z@@&`),&F[!&W>D69_883^K58T?Q``<6ZP@"
M3^J`=D_JD`C>Z0`!2.J,>`&31_$``\WI!B,-]31^W>D`(\WI``%(Z@8`2>H(
M`=WI`HE"Z@L"W>D&J]"GU^D`9XCJ``C-Z08!&NL""MWI``%+\0`+3^J5"5)&
M@!G-Z1*K>4%/\``+!D8*F`]&S>D69]WI$&=/ZMIJ2NI+&LWX!*"&Z@@&6T:P
M1MWI%F<V&$?Q``<6ZP@`3^J4"$_JA'9(ZH5XWND`14?Q``'-Z0H!40$`D=WI
M``$-]3A^S>D`14CJ!@1)Z@@%W>D&>-WI"KQ`Z@H`9T`N1B5&S>D*5KA&W>D`
M1::GU^D`9QOK``M,\0`,3^J3":096$9]0<WI$+PF1D_P``PO1LWI%F?=Z1)6
M3^K;:MWI%F=*ZDP:A>H(!<WX!*!A1JA&`IUV&4?Q``<6ZP@$3^J2"$?Q``5(
MZH-XMJO-Z0)%E@=$`0"4T^D`(]WI`$4`)<WI`"-(Z@8"2>H(`]WI"HE$Z@H$
MW>D"JX.GU^D`9XCJ`@C-Z0(C&NL$"MWI`"-+\0`+5$;-Z1*KDAE/ZMIJ>T%*
MZD4:%D;-^`2@'T;-Z19GW>D09T_JD0D&FX;J"`:P1MWI%F?V&$?Q``<6ZP@"
M1_$``\WI!B-C`0"3W>D`(T_JD`C=Z0:\2.J!>$+J"@*&!QOK`@M/\``*3/$`
M#,WI%KQ:1D_P``O-Z0"K2.H&"DGJ"`O=Z0)XT4;>Z0`!A^H)!]8.VD8`ELWI
M$)JX1MWI$JM/\``,5*?7Z0!G8T:*Z@@*-A@`F$]!S>D&9T#J3![01@J85@'=
MZ0:K3^J5"\WX`.``)QKK``K8#@&0&NL(`-WI`(E/ZI0*2NJ%>KJM2.H&"$OJ
M"@$0ZP@`3^J$>(M&!D9*Z@@`S>D`9]7I`&>"1MWI`(G-Z0JK04;=Z1")R`Z(
MZ@H(#_+4"]OI`*L:ZP8*5D;=Z0"K0.I+'MWI%JL"F(KJ"`K-^!C@-AC01MWI
M`*M91L@.448'D$P!`"``(<WI`@$6ZP@`W>D&>)8(`I9/ZH)Z`IDG0\89W>D`
M14'JC'$"D=WI!`&9"``C`Y&`&=WI#F?=Z0*)`"<"1AJ82.H*"-WX],(`(<#I
M`"/=Z0PC"IND&/88&YNB1MWI%$7`Z09G`"73^`#@$)OD&-WI"",`(Q+K"`+T
M19!&4D;`Z0(C`D;"Z0A%0$;"Z00!`]$-]3]]O>CPC_SW4NH`O];!8LH`````
M`"@\T"WI^$-+\C@3P/("`]/X`)"Y\0`/+M`%>#TM&+\`+12_`24`)171V?@`
M0'RQ@$8/1DY&*D9!1B!&_/=4ZQ"Y8UT]*P_05O@$3P`L\M$@1KWH^(,%1A7X
M`3\]*QB_`"OYT2T:X.?)ZP8&:!P@1+80/F"]Z/B#2$:]Z/B#<$=PM4OR0!7`
M\@(%@K`K:$OR.!8$1L#R`@8!DVE&($;_]Z__J+$`F#%H`>N``UIH0?@@(``J
M\=`$,U/X!"]#^`0L`"KYT6E&($;_]YK_`"CIT0&:*VB:0@'1`K!PO?SWW.DM
MZ?!/2_)`%0MXP/("!0Q&*F@]*X6P"+\!-`9&`Y(@1OSW2NH"J0=&,$;_]WG_
M@D8`*%?0_/=`ZH="2MD"FTOR.!G`\@()3^J#"#!X/2@8OP`H%+\!(``@!]`P
M1A#X`3\]*QB_`"OYT8`;`C?9^`"0.$1+\C@7_/?\Z<#R`@=)^`@``"ALT#IH
M<1P"F#-X4O@@```K&+\]*P-P"=!"'!'X`3L01@`K&+\]*P+X`3OVT0)&/2,#
M<!3X`3L"^`$_`"OYT0`@`YHK:)I"3-$%L+WH\(\*\?\P%/@!.P#X`3\`*_G1
M[N=+\C@9P/(""=GX`+#;^```B+-;1E/X!"\*\0$*`"KYT0KQ`@&)`$OR:!/`
M\@(#&FAZL5A&_/=BZ<GX``#PL4_JB@@*\0$#`")`^",@S?@(H(GG"$8!(AI@
M_/>8Z0&0:+%/ZHH(649"1OSW^.@!FQA&R?@`,.7G@D8((=3G3_#_,*[G_/<H
MZ0"_+>GP04OR0!7`\@(%GK`K:!V3$+$#>`=&,[D=FBMHFD)2T1ZPO>CP@?SW
M8.D&1@`H\]`P1OSW$NJ8L\-\+BLWT`#Q$P0X1OSW@NF`1B!&_/=^Z4!$`C#\
M]U;I1O+\<\#R`0-/\/\R`2$!E`"7@$;\]XSI048"J@,@_/<*Z@$P0$8%T`:;
M`_1P0[/U@$\9T/SW[.A`1OSWI.@P1OSWX.D`*,O1,$;\]Q+J.$;\][CHM.<#
M?0`KO=`N*\+10WT`*[C0ON?_]YW_Y.?\]\#H<+5+\D@4P/("!"!H_/?^Z=#X
M@#`@:%YH_/?XZ9#X95`@:/SW].D%\'\%0V@;BL/S"`-%ZL,5=8`@:/SWZ.G0
M^(`P(&A=:/SWXNE&]@PQ`"+`\@$!_/<FZ>AA(&C\]];IT/B`,"!H76C\]]#I
MT/C@-"!H*V+\]\KIT/B`,"!H76C\]\3IT/C\,"NQ(&C\][[IT/C\,!MO:V(`
M)2!H_/>VZ=#X@#`@:%MHG6+\][#IT/B`,"!H6VB=8?SWJ.G0^(`P(&A<:/SW
MHNG0^!@RXV)PO3BU2_)(%,#R`@0%1B!H_/>6Z2E&`/6$<@,@_/>$Z0BQ`"`X
MO2!H_/>*Z=#X&#$#]'!#L_6`3PG0(&C\]X#IT/@8,0/T<$.S]2!/Z=$H1@(A
M_/<>Z;#Z@/!`"3B]\+5+\D`4K?6`7<#R`@2#L"-H#?6`509&!#5&]@0`#T;`
M\@$``:E`]O]R*V#\]SCH`"@CW44>`:M;7>NQ!48J1B\A`:C\]_#HP+%+\D@3
MP/("`QAH_/=$Z2M&`:HQ1OSW".D-]8!3!#,::"-HFD(1T0WU@%T#L/"]`"W@
MT4OR2!/`\@(#&&C\]RSI.D8Q1OSW`NCFY_OWWN]+\D@3P/("`Q"U&&C\]QSI
M1O*`<T'R[%)&]A0!P/(!`\#R`0+`\@$!O>@00/SW>+@0M4OR2!3`\@($@K`@
M:/SW!.G_]]W_(&C\]_[H1O8,,T;RT3)&]C`!P/(!`\#R`0(`D\#R`0$`)`&4
M_/>,Z`*P$+T`OW"U2_)`%*WU`%W`\@($AK`C:`WU`%(4,A-@_/<*Z$;V5`)&
M]D@#P/(!`L#R`0,!D@$A0?(!`@"0`ZC\]R3H`"@BVPWU@%$#J$_T@%(0,?OW
MHN\%'AC;:!S[]]+O!D:HL0WU@%$J1A`Q^_=$[S!&`"-S50WU`%,4,QIH(VB:
M0@;1#?4`70:P<+T`(/+G\>?[]USO`+__][2_+>GP3TOR0!:M]8!=P/("!H>P
M,V@-]8!2!$84,D;V7``/1L#R`0`$J1-@__?U_"\A!48@1OOWR.^@L4;V:``A
M1L#R`0#_]UC]($8-]8!3%#,::#-HFD)`\)"`#?6`70>PO>CPCR!&^_>D[T;V
M>`'`\@$!@48X1OSW$NB"1@`HW-!&]E@'1O:$",#R`0?`\@$(FO@`,``K"+^Z
M1BVQ448H1OOWLNX`*$S04$;[]X+O"NL``Q/X`3PO*PC10QX`(5-$&7`!.!/X
M`2TO*OG0"?$!`QA$L/6`7[#:1O9\`TOR2!M/](!2`2'`\@$#`I3-^`2`!:C-
M^`"@P/(""_OW>._;^```_/<<Z`6I`/6$<@,@^_?R[U"YV_@``/SW$.C0^!@Q
M`_1P0[/U`$\6T$;V>`$`(,#R`0'[][+O@D:Z\0`/I]%[YT;V>`'`\@$!^_>H
M[X)&NO$`#YS1<.<!(06H^_>8[P`HXM%&]F@`!:G`\@$`__?#_`6H^_=([V?G
M^_>:[@"_`W@[L4(<+RL(OQ!&$O@!.P`K^-%P1P"_.+6(LP5X!$9UL_OW!N\!
M.",8G$(,TB)<+RHOT5H>`N`9>"\I*M&B0A-&`O'_,O?1G$(7T`$[`N`1>"\I
M!-&<0AI&`_'_,_?3$AN3'+/U@%\2V`$R(49/](!3$DC[]U;N$$@XO2\M%-$"
M(/OWLNX#1A"Q+B(:@#B]`"`XO5H>`N`9>"\IUM"40A-&`O'_,O?3SN=&]H0`
MP/(!`+WH.$#[]^6^`+]LL0(`\+6-L%]-`JQ+\D`6P/("!@_--V@/Q`_-"Y<M
M:`_$1O:(`,#R`0`E@/_W%OQ&]I0`P/(!`/_W$/Q&]IP`P/(!`/_W"OQ&]J@`
MP/(!`/_W!/Q&]K``P/(!`/_W_OM&]L``P/(!`/_W^/M&]EP`P/(!`/_W\OM&
M]LP`P/(!`/_W[/M&]M@`P/(!`/_WYOM&]N0`P/(!`/_WX/M&]F@`P/(!`/_W
MVOM&]O``P/(!`/_WU/M&]OP`P/(!`/_WSOM&]@@0`:G`\@$`__>'^P%&*+%&
M]M@`P/(!`/_W[_M&]AP0`:G`\@$`__=X^P%&*+%&]C`0P/(!`/_WX/M&]CP0
M`:G`\@$`__=I^P%&J+%&]EP`P/(!`/_WT?M&]FP11O:P`,#R`0'`\@$`__?'
M^PN:,VB:0B71#;#PO4;V3!`!J<#R`0#_]TK[`48PL4;VS`#`\@$`__>R^]_G
M1O9@$0HBP/(!`0WQ&0#[]ZSN`"C4T4;VS``-\2,!P/(!`/_WGOO+Y_OW>.T`
MOXQG`0`PM4OR0!1+\BP5P/("!"-HP/("!8.P*&@!DT,<!=`!FB-HFD(2T0.P
M,+U&]LP`:4;`\@$`__<,^S"Q`'@`*!B_,"@4OP$@`"`H8.CG^_=,[0BU^_<(
M[?OW^NP`L0!H"+TMZ?!'!T8L3(ZP!JU+\D`8P/(""`_,V/@`8`_%E.@'``:<
M#9:%Z`<`[+%&]G@)!JW`\@$)!N`Y1OOWS.S8L57X!$^$L06I($;_]]+Z!D80
ML0-X`"OOT2!&.4;_]SG[5?@$3P`L[M$-FMCX`#":0B#1#K"]Z/"'.$;[]X;M
M@D8P1OOW@NU01`(P^_=:[4;V?`,"EL#R`0/-^`203_#_,@"7`2&"1OOWCNU1
M1B!&__<0^\7G^_?J[`"_L&<!`"WI\$\%1L1,K?4!39&P2_)`$P3Q#`P2KY3H
M!P#`\@(#T_@`@`WQ8`X)DR0T%:X-]0%)A^@'``GQ/`F\Z`\`R?@`@*[H#P"<
MZ`,`CN@#`)3H!P"&Z`<`1O9<`!&IP/(!`/_W:/H@L0-X!$8`*T#PAH'_]V#_
M@$8`*%/00$;[]R;M0``!,/OW_NR8^``@!D8$1GJQ1O9X$P"2($9/\/\RP/(!
M`P$A^_<P[1CX`2\"-``J[]$8F!BL&+D4X%3X!`^(L1&I__<W^H!&`"CVT`-X
M`"OST/_W(_P`*._00$;[]R+M@49PNQ*<5+,C>$_P`0@[N27@5_@H0!2S(W@(
M\0$(\[$@1O_W"_P`*//0($;[]PKM`"CNT(%&%.#[]P3M`"A`\#F!5O@$"P`H
M`/`N@1&I__<!^@`H]=`#>``K\M#LYT_P``E(1D;VA`O[]\#LP/(!"P1&,$;[
M][KL($0`\@1$($;[]Y#L1O:,$D;V@!/`\@$"P/(!`P*2`2%/\/\R`Y;-^`"0
MS?@$L()&^_>^[%!&3_3@<?OWUNP!,"O02_)(%L#R`@8P:/OW6.U11@#UA'(#
M(/OW1NV@LTOR4!%&]A0BP/("`2MH"&C`\@$"S?@`H`$A^_?:[``@#?4!0SPS
M&F@)FQMHFD)`\*^"#?4!31&PO>CPC_OWA.P!:!$ISM!+\E`01O:4$L#R`@`K
M:`!HP/(!`@&1`2'-^`"@^_>V[``@VN<P:/OW&NW0^!@Q`_1P0[/U@$_`T3!H
M^_<0[=#X(''[]X3KAT*WT3!H^_<&[=#X&#'#\P@#L_7@?ZW1($;[]Q+L$:D$
M1D;V8##`\@$`__=B^0`H`/!F@BYH^_=4[`%&,$;_]TS\!D8`*`#P6X(P1OOW
M'NP#*`=&$=T$.$;VT!$P1,#R`0'[]S[K0+D$+P#PX8$W1!?X!3PO*P#PVX'_
M]Q+^,+D!1C!&^_?8ZPR0`"ACT4;V;!%&]LP`P/(!`<#R`0#_]YCY1O8,-_OW
MY.M&]O`3P/(!!\WX!+`#E\#R`0/-^`"@3_#_,@$AN$8`)E=&`I`@1OOW^NL9
MX,QG`0#[]^[K`V@1*QK1^_?&ZT;V`",!-LWX$(`#EBI&S?@$L,#R`0,`EP$A
M`I`@1OOWWNM/].!Q($;[]_;K0QP%1M_0ND901OOW_NI&]EP`(4;`\@$`__=1
M^2!&__?F_2!&+.?_]^+]($;[]]#K)N=&]G`8#2#`\@$(=^:`1G#F3_#_,V_P
M$0(")0"5^_=0ZT^I!B(,F/OWQNJ=^#PQ([F=^#TQ0RL`\(B!`"4`(@`C`)4,
MF/OW/.O>H='I``'?H]/I`"/?I]?I`&?-Z2`!+*D\E<WI(B,-1MRCT^D`(]VA
MT>D``<WI)&?-Z1XCS>DF`0`@`"$-E,WI*`'-Z2H!S?@XH,WX/+!/]`!"3ZD,
MF/OWBNH$'G3=W>DH(T_JQ`I/\``))D8:ZP((F44(OY!%3^KD=]WI*B,"T@$R
M0_$``W$//)A!ZL<!!I%Y#P>1W>D&9\WI*(FV&%]!,D8[1LWI*B,`*$K0P/%`
M"!ZKH$4`\3@`&$1/J:B_H$9"1OOW<NH\FT-$/)-`*[[13ZL>J,CK!`281/OW
M0_T_+"?=I/%``PCQ0`P*DYP)!/$""0CKB1FL\4`&KD8P:!`V5O@,''=&5O@(
M+`[Q$`Y6^`0\9D4/Q_'1'JC[]R/]!O%`#,Q%Y]%C'`J:".N#&*+KA!1!1D@C
M(D8H1OOWC.H\E(7G#?6>>,KG#*B0Z!$,^_>*ZQZK*)V`("J>Q?/%`ID84QPX
M*X'X.``"\3D``/.O@!ZKPO$W`AA$`"'[]P#K'J@R#C,,C?CK8(WX[U`V"HWX
MZ"`-]8AXC?CI,"L.C?CJ8`WR#Q>-^.PP*PPM"HWX[3"-^.Y0^_?6_-WX>,`_
MKMWX@.`BF"293^H<12:;3^H<8HWX_\!/ZAPLC?C]4$5&C?C^P$_J'FR-^`/A
MC?@`P4_J'DR-^`<!3^H>+HWX"Q&-^`+A3^H0;HWX#S&-^`3A3^H03HWX_"``
M"HWX!>%/ZA%NC?@&`0@,C?@(X0D*3^H3;HWX"0&-^`'!&`R-^`H1&PJ-^`SA
MC?@-`8WX#C$!X!;X`2]&]G@3`)(H1L#R`0-/\/\R`2'[]VCJOD(%\0(%[M%&
M]@PQ1O;@$\WX"(#`\@$!S?@$L``E`Y'`\@$#S?@`H$_P_S(!(2!&B/@H4/OW
M3.IUYFUH`"T_]"&N*$;[]R;J`RA_]ANN!#A&]M@1*$3`\@$!^_=(Z0`H"+\N
M1@[F'JO"\3\"&$0`(?OW4.H>J/OW0?P`(RR3+9,NDR^3,),QDS*3,Y,TDS63
M-I,WDSB3.9,]YYWX/C%!*W_T<ZZ=^#\Q0RM_]&ZNG?A`,4@K?_1IKIWX03%%
M*W_T9*X`E4_P_S,,G6_P.0(H1OOWGNE/J2A&*2+[]Q3I1O8,,D;VX!-/J<#R
M`0("D0.2P/(!`\WX!+!/\/\RS?@`H`$A($;[]^3I#>8N:*+E^_="Z0"_B:O-
M[P````#^W+J8`````'94,A```````2-%9P````#PX=+#`````"WI\$]+\D`3
MA;#`\@(#2_)(%P&3P/("!QMH.&@#D_OW8NH!(P*I@/AA,$;VL`#`\@$`_O?%
M_ABQ`W@Q*P#PV8#_]]+Z.&A,\F`F^_=,ZD;V:"'`\@$!"R,!(OOW9ND`*`#P
MS(#`\@(&`FE6^/0\`2O2^!B0.]U+\D@:`"7`\@(*`20DX`)H3_2`8U;X\`S`
M\B`#D6A0^"2`"T"S]8!O"+\1:0K0VO@``/OW'.K;^``0`B,`(OOW`ND!1D!&
M^_=XZ%;X]#R`N0$T`36C0@S=.&C[]PCJ`",J1DE&^_>ZZ8-&`"C/T5;X]#Q:
M'JI"<M`X:$OR2!3[]_;I1O9P(<#R`0$#(P$BP/("!/OW#ND%1H"Q(&C[]^CI
M*VE&]G0BP/(!`AEH^_>ZZ"MI&VB;:%L"`/&W@#AH2_)(%/OWU.E&]GPAP/(!
M`0,C`2+`\@($^_?LZ`5&F+%&]F@``JG`\@$`_O<O_H!&(&BX\0`/`/"/@/OW
MNNDK:4)&&6C[]X[H.&A+\D@9^_>PZ0`B`JE,\F`DP/(""<#R`@0#1D;V7`#`
M\@$`@_AA(/[W#/Z`1D;X[`Q`LT_TX''[]PKI0AP#1A$H&+\!*GW8`9L#FAMH
MFD)VT06PO>CPCP$KBMT!)#AH`33[]X+I24;[]PCH5OCT/*-"]-Q]YT-X`"L_
M]"6O(>?`\@(&=>=4^/`,__=!^T3X[`P`*$[0*FE/](!CP/(@`Q)HD6@+0+/U
M@&\(OQ!I"=#9^```^_=8Z2EI0D8"(PEH^_<^Z%;X\$PA1OKWY.\J:4_T@&,D
M:,#R(`,2:)%H"T"S]8!O"+\2:09&"=`X:/OW/.DI:0`B`B,):/OW(N@"1D;V
MI"`S1B%&P/(!`/OWBNC[]RKI5OCP+"MI$6@8:/[WL_]MYR!H^_<@Z2MI&6C[
M]ZCH0.=&]H`@P/(!`/OW<NCZ]\SO5/CP'$;VS"!"1L#R`0`):/OW9N@XM05&
M__<R^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_]SWZ`"@8OP`M"M`K>$.Q1O:,
M$2!&P/(!`?KW2N^$0@#0.+TH1KWH.$#^]W:^$+5+\D@4P/("!"!H^_?:Z$_P
M_S'Z]]3O(&C[]]3H1?*I0<#R`0$`(KWH$$#[]YZX`DM[1`.Q&VCZ]X2_`DH!
M`"WI^$,'1@Q.B$8,39%&?D3Z]PCO?41V&[80"M`$/0`D`315^`0_.$9!1DI&
MF$>T0O;1O>CX@P"_MD<!`*Q'`0!P1P"_"$`MZ0B`O>@!``(`<&5R;'AS:2YC
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````0&L!`%!K
M`0!8:P$`8&L!`&AK`0!\:P$``````#AK`0!8:`$``````#!I`0`T:0$`+&L!
M`&!H`0`T:P$``````!AK`0`@:P$``````"5S+R5S````+W!R;V,O<V5L9B]E
M>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!
M4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$52
M3$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!0
M05)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'`````%!!
M4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```%-94U1%30``
M)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A
M<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,`````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``05)'5@`````8````<&5R;``````P````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U=&EO;B!O
M9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M````+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T
M;7``````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(````
M`$193$1?3$E"4D%265]0051(````4TA,24)?4$%42```979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.
M5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?
M)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!
M4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@
M)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*<V5E:R!?1D@L("TX+"`R
M.PIR96%D(%]&2"P@)&)U9BP@.#L*;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y0
M05(N<&U<;B(["G-E96L@7T9(+"`M,3(L(#(["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@
M7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@
M)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE;F%M92D@/2!?
M=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U
M="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@
M)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PIO=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@
M)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H
M("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D
M9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA
M;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*:68@
M*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D9FEL96YA;64M
M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G/"<L("1N86UE
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H
M4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q
M=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@
M<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*?2!G<F5P('L*(2]"
M4T1004XO"GT@9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B]>
M7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@
M)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H
M)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M
M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.
M?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#([
M"G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H
M)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@
M86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H
M*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY
M("@D9F@L("1F:6QE;F%M92D["B1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R
M8R1E>'0B.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA
M;64@:68@+64@)&9I;&5N86UE.PIP=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M"GT*96QS92!["G)E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F
M:6QE;F%M92D["GT*;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PIR971U<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*`"1S_W\!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&T;`0!5&P$```````$````!`````0````4"```!````
M5`(```$```"G`P``#````%05`0`-````=&<!`!D```#TK@(`&P````0````:
M````^*X"`!P````$````]?[_;[0!`0`%````=`P!``8```!T!0$`"@```#\%
M```+````$````!4``````````P````"P`@`"````*`(``!0````1````%P``
M`"P3`0`1````]!(!`!(````X````$P````@```#^__]OE!(!`/___V\#````
M\/__;[01`0``````````````````````````````````````````````````
M````````````````KP(```````````!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5
M`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!
M`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`
M8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@
M%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5
M`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!
M`&`5`0!@%0$`8!4!`&`5`0!@%0$`8!4!`&`5`0````````````````#_____
MB&L!`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XY+C(M,3!U8G5N='4W*2`T+CDN
M,@!'0T,Z("A58G5N='4O3&EN87)O(#0N."XT+3%U8G5N='4T*2`T+C@N-`!!
M-````&%E86)I``$J````!3<M00`&"@=!"`$)`@H$$@03`10!%0$7`Q@!&0$:
M`AL#'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E
M+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````
M````````````````````````````````````"P````$````"````5`$!`%0!
M```9```````````````!`````````!,````'`````@```'`!`0!P`0``(```
M````````````!``````````A````!P````(```"0`0$`D`$``"0`````````
M``````0`````````-````/;__V\"````M`$!`+0!``#``P``!0`````````$
M````!````#X````+`````@```'0%`0!T!0````<```8````!````!````!``
M``!&`````P````(```!T#`$`=`P``#\%``````````````$`````````3@``
M`/___V\"````M!$!`+01``#@````!0`````````"`````@```%L```#^__]O
M`@```)02`0"4$@``8`````8````#````!`````````!J````"0````(```#T
M$@$`]!(``#@````%``````````0````(````<P````D```!"````+!,!`"P3
M```H`@``!0````P````$````"````'P````!````!@```%05`0!4%0``#```
M````````````!`````````!W`````0````8```!@%0$`8!4``&`#````````
M``````0````$````@@````$````&````P!@!`,`8``"T3@`````````````(
M`````````(@````!````!@```'1G`0!T9P``"```````````````!```````
M``".`````0````(```!\9P$`?&<``!!```````````````0`````````E@``
M``$``'""````C*<!`(RG```(````#0`````````$`````````*$````!````
M`@```)2G`0"4IP``!```````````````!`````````"K````#@````,```#T
MK@(`]*X```0```````````````0`````````MP````\````#````^*X"`/BN
M```$```````````````$`````````,,````!`````P```/RN`@#\K@``!```
M````````````!`````````#(````!@````,`````KP(``*\````!```&````
M``````0````(````T0````$````#`````+`"``"P```D`0`````````````$
M````!````-8````!`````P```"2Q`@`DL0``$```````````````!```````
M``#<````"`````,````XL0(`-+$``$00``````````````@`````````X0``
M``$````P`````````#2Q``!5```````````````!`````0```.H````#``!P
M``````````")L0``-0```````````````0`````````!`````P``````````
;````OK$``/H```````````````$`````````
